This function returns a random print output that can be passed to renderPrint and verbatimTextOutput.
Usage
random_print(type = c("character", "numeric", "integer", "model", "table"))This function returns a random print output that can be passed to renderPrint and verbatimTextOutput.
random_print(type = c("character", "numeric", "integer", "model", "table"))