This function returns a table that can be passed to renderTable and tableOutput.
Usage
random_table(nrow, ncol, type = c("random", "numeric", "character", "numchar"))This function returns a table that can be passed to renderTable and tableOutput.
random_table(nrow, ncol, type = c("random", "numeric", "character", "numchar"))